#include <main.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <lcd.h>
#include <i2cmaster.h>
#include <avr/eeprom.h>

#include <util/delay.h> 
#include <string.h>
#include <stdio.h>

extern uint8_t vfo;

extern uint16_t leds;					// Zustand der LEDs
extern uint16_t Rx_Relais;				// Relais auf dem Rx Board
extern uint16_t Tx_Relais;				// Relais auf dem Tx Board

extern uint16_t EE_LED			EEMEM;	// I2C LED Status
//extern uint16_t EE_Rx			EEMEM;	// Relais fr Rx Platine
//extern uint16_t EE_Tx			EEMEM;	// Relais fr Tx Platine
extern uint16_t EE_LED_A		EEMEM;	// I2C LED Status
extern uint16_t EE_LED_B		EEMEM;	// I2C LED Status
///////////////////////////////////////////////////////////////////////////////
//
//	Initialisieren
//
//////////////////////////////////////////////////////////////////////////////
void pcf9555_init (void)
{
	int temp = 0;
	uint8_t lower, upper = 0;
	lower = (uint8_t)leds;
	upper = (uint8_t)(leds>>8);

	temp = i2c_start(0x40 + I2C_WRITE);						// schreibe Daten ins IC
	if (!temp)
	{
		i2c_write(0x06);									// ndere Port 0 Konifguration
		i2c_write(0x00);									// ndere Port 0 zu Ausgnge
		i2c_write(0x00);									// ndere Port 1 zu Ausgnge
		i2c_stop();
	}
	else 
	{
		lcd_clrscr();					// lsche alles
		lcd_puts("Probl. I2C Front LED");
	}
	temp = i2c_start(0x4E + I2C_WRITE);						// schreibe Daten ins IC
	if (!temp)
	{
		i2c_write(0x06);									// ndere Port 0 Konifguration
		i2c_write(0x00);									// ndere Port 0 zu Ausgnge
		i2c_write(0x00);									// ndere Port 1 zu Ausgnge
		i2c_stop();
		i2c_start(0x4E + I2C_WRITE);						// schreibe Daten ins IC
		i2c_write(0x02);									// schreibe in Ausgangsregister
		i2c_write((uint8_t)Rx_Relais);						// ausgeben der unteren 8 bit
		i2c_write((uint8_t)(Rx_Relais>>8));					// ausgeben der oberen 8 bit
		i2c_stop();											// stop aktuelle Kommunikation

	}
	else 
	{
		lcd_clrscr();					// lsche alles
		lcd_gotoxy(0,1);
		lcd_puts("Probl. I2C Rx Filter");
	}
	temp = i2c_start(0x46 + I2C_WRITE);						// schreibe Daten ins IC
	if (!temp)
	{
		i2c_write(0x06);									// ndere Port 0 Konifguration
		i2c_write(0x00);									// ndere Port 0 zu Ausgnge
		i2c_write(0x00);									// ndere Port 1 zu Ausgnge
		i2c_stop();
		i2c_start(0x46 + I2C_WRITE);						// schreibe Daten ins IC
		i2c_write(0x02);									// schreibe in Ausgangsregister
		i2c_write((uint8_t)Tx_Relais);						// ausgeben der unteren 8 bit
		i2c_write((uint8_t)(Tx_Relais>>8));					// ausgeben der oberen 8 bit
		i2c_stop();											// stop aktuelle Kommunikation
	}
	else 
	{
		lcd_clrscr();					// lsche alles
		lcd_gotoxy(0,2);
		lcd_puts("Probl. I2C Tx Filter");
	}

// Fehlerhandling fr fehlerhafte I2C Kommunikation eingeben. Fehlerarray oder hnliches
}

///////////////////////////////////////////////////////////////////////////////
//
//	Alle LEDs aussschalten
//
//////////////////////////////////////////////////////////////////////////////

void pcf9555_aus (void)
{
		i2c_start(0x40 + I2C_WRITE);						// schreibe Daten ins IC
		i2c_write(0x02);									// schreibe in Ausgangsregister
		i2c_write(0x00);									// 
		i2c_write(0x00);									// 
		i2c_stop();											// stop aktuelle Kommunikation
}

///////////////////////////////////////////////////////////////////////////////
//
//	Alle LEDs anschalten
//
//////////////////////////////////////////////////////////////////////////////

void pcf9555_an (void)
{
		i2c_start(0x40 + I2C_WRITE);						// schreibe Daten ins IC
		i2c_write(0x02);									// schreibe in Ausgangsregister
		i2c_write(0xFF);									// 
		i2c_write(0xFF);									// 
		i2c_stop();											// stop aktuelle Kommunikation
}

///////////////////////////////////////////////////////////////////////////////
//
//	Einzelne LEDs an der Frontplatte schalten
//	I2C Adresse = 0x40 schreiben
//				  0x41 lesen
//
//////////////////////////////////////////////////////////////////////////////

void LED_onoff(uint8_t i2c_chip)
{
	uint8_t temp  = 0;
	if (i2c_chip == Init)
	{
		temp = i2c_start(0x40 + I2C_WRITE);				// Frontplatte LED
		if (!temp)										// IC vorhanden
		{
			i2c_write(0x02);							// schreibe in Ausgangsregister
			i2c_write((uint8_t)leds);					// ausgeben der unteren 8 bit
			i2c_write((uint8_t)(leds>>8));				// ausgeben der oberen 8 bit
			i2c_stop();									// stop aktuelle Kommunikation
		}
		temp = i2c_start(0x4E + I2C_WRITE);				// Rx Board
		if (!temp)										// IC vorhanden
		{

			i2c_write(0x02);							// schreibe in Ausgangsregister
			i2c_write((uint8_t)Rx_Relais);				// ausgeben der unteren 8 bit
			i2c_write((uint8_t)(Rx_Relais>>8));			// ausgeben der oberen 8 bit
			i2c_stop();									// stop aktuelle Kommunikation
		}
		temp = i2c_start(0x46 + I2C_WRITE);				// Tx Board
		if (!temp)										// IC vorhanden
		{
			i2c_write(0x02);							// schreibe in Ausgangsregister
			i2c_write((uint8_t)Tx_Relais);				// ausgeben der unteren 8 bit
			i2c_write((uint8_t)(Tx_Relais>>8));			// ausgeben der oberen 8 bit
			i2c_stop();									// stop aktuelle Kommunikation
		}
	}
	else if (i2c_chip == Front_LED)						// Frontplatten LED
	{
		i2c_start(0x40 + I2C_WRITE);					// schreibe Daten ins IC
		i2c_write(0x02);								// schreibe in Ausgangsregister
		i2c_write((uint8_t)leds);						// ausgeben der unteren 8 bit
		i2c_write((uint8_t)(leds>>8));					// ausgeben der oberen 8 bit
		i2c_stop();										// stop aktuelle Kommunikation
		if (vfo == 0x00)
			eeprom_write_block((uint16_t*)&leds, (uint8_t*) &EE_LED_A, sizeof(uint16_t));//LED Zustnde speichern
		else 
			eeprom_write_block((uint16_t*)&leds, (uint8_t*) &EE_LED_B, sizeof(uint16_t));//LED Zustnde speichern
	}
	else if (i2c_chip == Rx)
	{
		i2c_start(0x4E + I2C_WRITE);					// schreibe Daten ins IC
		i2c_write(0x02);								// schreibe in Ausgangsregister
		i2c_write((uint8_t)Rx_Relais);					// ausgeben der unteren 8 bit
		i2c_write((uint8_t)(Rx_Relais>>8));				// ausgeben der oberen 8 bit
		i2c_stop();										// stop aktuelle Kommunikation
	}
	else if (i2c_chip == Tx)
	{
		i2c_start(0x46 + I2C_WRITE);					// schreibe Daten ins IC
		i2c_write(0x02);								// schreibe in Ausgangsregister
		i2c_write((uint8_t)Tx_Relais);					// ausgeben der unteren 8 bit
		i2c_write((uint8_t)(Tx_Relais>>8));				// ausgeben der oberen 8 bit
		i2c_stop();										// stop aktuelle Kommunikation
	}
}
