// RIT 
//
// ndert die Rx Frequenz um +/- 9,9 kHz. Tx bleibt aber bestehen
//
// Marcus Pool, DG9BFJ
//
// www.Marcus-Pool.de
//
// Revision: 0.1
// 
// 08.10.11


#include <main.h>
#include <avr/io.h>
#include <stdlib.h>
#include <stdint.h> 
#include <stdio.h>
#include <dds.h>
#include <lcd.h>
#include <lcd_menu.h>
#include <outputs.h>
#include <util/delay.h>
#include <avr/eeprom.h>

extern uint16_t leds;						// Zustand der LEDs
extern int16_t xrit_hz_temp;				// Frequenz fr RIT/XIT

extern uint32_t freq_hz;					// speichert die Frequenz in Hz

extern struct BitVariablen{
    int menu_aktiv		:1;					// ein Men ist aktiviert
	int freq_input  	:1;					// Frequenzeingabe via 10er Tastatur aktiviert
	int	freq_update 	:1;					// 
	int freq_update_lcd	:1;					// auf dem LCD Frequenz aktualisieren
	int tx_on			:1;					// Sender eingeschaltet
	int ptt_schalten	:1;					// PTT umgeschaltet
	int rit_aktiv		:1;					// RIT Funktion aktiv
	int xit_aktiv		:1;					// XIT Funktion aktiv
}bitvar;

///////////////////////////////////////////////////////////////////////////////
//
//	RIT und XIT ausschalten
//
///////////////////////////////////////////////////////////////////////////////
void rit_off(void)
{
	bitvar.rit_aktiv = 0;	// RIT aus
	bitvar.xit_aktiv = 0;	// XIT aus
	leds &= RIT_aus;		// dann LED aus
	leds &= XIT_aus;		// dann LED aus
	lcd_gotoxy(7,2);		
	lcd_puts("             ");
	xrit_hz_temp = 0;		// Frequenz fr RIT/XIT = 0
	LED_onoff(Front_LED);
}

///////////////////////////////////////////////////////////////////////////////
//
//	Activiere RIT LED
//	- toggelt RIT LED
//
///////////////////////////////////////////////////////////////////////////////
void rit_LED(void)
{
	key_beep_short();
	if (leds & RIT_an)			// ist das bit gesetzt? Dann aus.
	{
		bitvar.rit_aktiv = 0;	// RIT aus
		leds &= RIT_aus;		// dann LED aus
		lcd_gotoxy(7,2);		
		lcd_puts("             ");
		xrit_hz_temp = 0;		// Frequenz fr RIT/XIT = 0
		convertDDS(freq_hz);	// Ausgabe der alten Frequenz ohne RIT zum DDS
	}
	else if (bitvar.xit_aktiv == 0)// aktiviere RIT
	{
		bitvar.rit_aktiv = 1;	// RIT an
		leds |= RIT_an;			// dann LED an
		lcd_gotoxy(14,2);
		lcd_puts("kHz Rx");
		xrit_hz_temp = 0;		// Frequenz fr RIT/XIT = 0
	}
	LED_onoff(Front_LED);
}

///////////////////////////////////////////////////////////////////////////////
//
//	Activiere XIT LED
//	- toggelt XIT LED
//
///////////////////////////////////////////////////////////////////////////////
void xit_LED(void)
{
	key_beep_short();
	if (leds & XIT_an)			// ist das bit gesetzt? Dann aus.
	{
		bitvar.xit_aktiv = 0;	// RIT aus
		leds &= XIT_aus;		// dann LED aus
		lcd_gotoxy(7,2);		
		lcd_puts("             ");
		xrit_hz_temp = 0;		// Frequenz fr RIT/XIT = 0
	}
	else if (bitvar.rit_aktiv == 0)	// aktiviere RIT
	{
		bitvar.xit_aktiv = 1;	// RIT an
		leds |= XIT_an;			// dann LED an
		lcd_gotoxy(14,2);
		lcd_puts("kHz Tx");
		xrit_hz_temp = 0;		// Frequenz fr RIT/XIT = 0
	}
	LED_onoff(Front_LED);
}


///////////////////////////////////////////////////////////////////////////////
//
//	Lese RIT oder XIT 
//
///////////////////////////////////////////////////////////////////////////////
void rit(int16_t xrit_wert)
{
	char Buffer[10];

    itoa( xrit_wert, Buffer, 10 );
	lcd_gotoxy(7,2);
	xrit_wert *= 10;

	if (xrit_wert >= 1000)		// positiver Wert grer 1000
	{
		lcd_puts(" ");
		lcd_data(Buffer[0]);
		lcd_puts(".");
		lcd_data(Buffer[1]);
		lcd_data(Buffer[2]);
	}
	else if (xrit_wert >= 100)	// positiver Wert grer 100
	{
		lcd_puts(" 0.");
		lcd_data(Buffer[0]);
		lcd_data(Buffer[1]);
	}
	else if (xrit_wert >= 10)	// positiver Wert grer 10
	{
		lcd_puts(" 0.0");
		lcd_data(Buffer[0]);
	}
	else if (xrit_wert <= -1000)	// negativer Wert kleiner 1000
	{
		lcd_data(Buffer[0]);
		lcd_data(Buffer[1]);
		lcd_puts(".");
		lcd_data(Buffer[2]);
		lcd_data(Buffer[3]);
	}
	else if (xrit_wert <= -100)	// negativer Wert kleiner 100
	{
		lcd_data(Buffer[0]);
		lcd_puts("0.");
		lcd_data(Buffer[1]);
		lcd_data(Buffer[2]);
	}
	else if (xrit_wert <= -10)	// negativer Wert kleiner 10
	{
		lcd_data(Buffer[0]);
		lcd_puts("0.0");
		lcd_data(Buffer[1]);
	}
	else if (xrit_wert == 0)
	{
		lcd_puts(" 0.00");
	}
	lcd_puts("0");
}

///////////////////////////////////////////////////////////////////////////////
//
//	RIT Anzeige im Display
//
///////////////////////////////////////////////////////////////////////////////
void display_RIT(void)
{
	if (leds & RIT_an)			// ist das bit gesetzt?
	{
		leds |= RIT_an;			// dann LED an
		ADCSRA = 0xE7;			// ADC off, FreeRunning, no Interrupt, CLK / 128
		bitvar.rit_aktiv = 1;	// RIT an
		lcd_gotoxy(14,2);
		lcd_puts("kHz Rx");
	}
	else 						// deaktiviere RIT
	{
		leds &= RIT_aus;		// dann LED aus
		ADCSRA &= ~(1 << ADEN);	// Disable ADC in Freerunning Mode
		bitvar.rit_aktiv = 0;	// RIT aus
		lcd_gotoxy(7,2);		
		lcd_puts("             ");
	}
	LED_onoff(Front_LED);
}

